==> biings-ds-1.12.0.tgz: package/docs/approach.md <==
<h6 class="subtitle is-5 has-text-grey">Principles</h6><h1 class="title is-1 has-text-weight-bold">Our approach</h1>
<p class="subtitle is-5">
    At Biings, we build products that enable corporate HR sustainability. Our mission is to improve occupational well-being in human organisations, no matter which domain of activity or organisational structure.
</p>

<p class="subtitle is-6">
    Our principles are at the heart of how we approach product design. They govern what we decide to create and should be kept in mind when building new features.
</p>

<hr class="is-visible is-large">

<div class="columns">
    <div class="column is-10 is-full-mobile">
        <div class="title is-4 has-text-weight-semibold">Put HR sustainability first</div><p class="subtitle is-6">
            Sustainable human ressources maintain the same level of corporate culture, knowledge and creativity within an organisation, and over time.
        </p>
        <hr>
        <h2 class="title is-4 has-text-weight-semibold">Favor responsibility and independance</h2><p class="subtitle is-6">
            Favor good work-atmosphere rather than adopting a coercive control of absences. Manage without judging.
        </p>
        <hr>
        <h2 class="title is-4 has-text-weight-semibold">Facts over surveys</h2><p class="subtitle is-6">
            Collecting factual data over information from surveys is key for a reliable analysis of occupational well-being.
        </p>
        <hr>
        <h2 class="title is-4 has-text-weight-semibold">Privacy by default</h2><p class="subtitle is-6">
            When releasing new product features, the strictest privacy settings should be applied by defaults.
        </p>
    </div>
</div>

==> biings-ds-1.17.0.tgz: package/docs/approach.md <==
<h6 class="subtitle is-5 has-text-grey">Principles</h6><h1 class="title is-1 has-text-weight-bold">Our approach</h1>
<p class="subtitle is-5">
    At Biings, we build products that enable corporate HR sustainability. Our mission is to improve occupational well-being in human organisations, no matter which domain of activity or organisational structure.
</p>

<p class="subtitle is-6">
    Our principles are at the heart of how we approach product design. They govern what we decide to create and should be kept in mind when building new features.
</p>

<hr class="is-visible is-large">

<div class="columns">
    <div class="column is-10 is-full-mobile">
        <div class="title is-4 is-serif">Put HR sustainability first</div><p class="subtitle is-6">
            Sustainable human ressources maintain the same level of corporate culture, knowledge and creativity within an organisation, and over time.
        </p>
        <hr>
        <h2 class="title is-4 is-serif">Favor responsibility and independance</h2><p class="subtitle is-6">
            Favor good work-atmosphere rather than adopting a coercive control of absences. Manage without judging.
        </p>
        <hr>
        <h2 class="title is-4 is-serif">Facts over surveys</h2><p class="subtitle is-6">
            Collecting factual data over information from surveys is key for a reliable analysis of occupational well-being.
        </p>
        <hr>
        <h2 class="title is-4 is-serif">Privacy by default</h2><p class="subtitle is-6">
            When releasing new product features, the strictest privacy settings should be applied by defaults.
        </p>
    </div>
</div>
